@@ -453,7 +453,7 @@ public class ColumnDataComboBoxModel
             return new SelectedColumnData( tcModel, tcol );
         }
         else {
-            ValueConverter conv = (ValueConverter)
+            ValueConverter conv =
                 info.getAuxDatumValue( TopcatUtils.NUMERIC_CONVERTER_INFO,
                                        ValueConverter.class );
             if ( conv != null ) {
@@ -500,8 +500,7 @@ public class ColumnDataComboBoxModel
          */
         SyntheticColumnData( TopcatModel tcModel, String expr )
                 throws CompilationException {
-            super( new ColumnInfo( expr ), expr, null,
-                   tcModel.createJELRowReader() );
+            super( tcModel, new ColumnInfo( expr ), expr, null );
             tcModel_ = tcModel;
             expr_ = expr;
         }
