@@ -1,7 +1,9 @@
 package uk.ac.starlink.topcat;
 
+import java.awt.Container;
 import java.awt.Desktop;
 import java.awt.Dimension;
+import java.awt.Rectangle;
 import java.awt.Toolkit;
 import java.awt.datatransfer.Clipboard;
 import java.awt.datatransfer.StringSelection;
@@ -26,6 +28,8 @@ import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JOptionPane;
+import javax.swing.JTable;
+import javax.swing.JViewport;
 import javax.swing.SwingUtilities;
 import javax.swing.table.TableColumnModel;
 import uk.ac.starlink.table.ColumnInfo;
@@ -357,6 +361,25 @@ public class TopcatUtils {
         }
     }
 
+    /**
+     * Scrolls a JTable as necessary to ensure that a given row index
+     * is scrolled to the visible part of the viewport.
+     *
+     * @param  jtab  JTable
+     * @param  irow   table index that must be visible
+     * @see  javax.swing.JList#ensureIndexIsVisible(int)
+     */
+    public static void ensureRowIndexIsVisible( JTable jtab, int irow ) {
+        Container tParent = jtab.getParent();
+        if ( tParent instanceof JViewport ) {
+            Rectangle vRect = ((JViewport) tParent).getViewRect();
+            Rectangle cRect = jtab.getCellRect( irow, 0, true );
+            Rectangle targetRect =
+                new Rectangle( vRect.x, cRect.y, vRect.width, cRect.height );
+            jtab.scrollRectToVisible( targetRect );
+        }
+    }
+
     /**
      * Alerts the user that the system has run out of memory, and provides
      * the option of some useful tips.
@@ -598,6 +621,22 @@ public class TopcatUtils {
             || ( o1 != null && o2 != null && o1.equals( o2 ) );
     }
 
+    /**
+     * Returns a string unique to an object's identity.
+     * This is modelled on the value that Object.toString() usually returns,
+     * though not guaranteed to be the same.
+     *
+     * @param   obj  object
+     * @return  unique string for object
+     */
+    public static String identityString( Object obj ) {
+        return new StringBuffer()
+              .append( obj.getClass().getName() )
+              .append( '@' )
+              .append( Integer.toHexString( System.identityHashCode( obj ) ) )
+              .toString();
+    }
+
     /**
      * Formats a long value for presentation as text.
      * This typically puts separators between groups of three numbers for
