@@ -18,6 +18,7 @@ import uk.ac.starlink.sog.SOG;
 import uk.ac.starlink.sog.SOGNavigatorImageDisplay;
 import uk.ac.starlink.sog.SOGNavigatorImageDisplayFrame;
 import uk.ac.starlink.table.ColumnData;
+import uk.ac.starlink.topcat.ColumnDataComboBox;
 import uk.ac.starlink.topcat.ColumnDataComboBoxModel;
 import uk.ac.starlink.topcat.ImageWindow;
 import uk.ac.starlink.topcat.LineBox;
@@ -74,12 +75,11 @@ public class GenericViewImageActivationType implements ActivationType {
     /**
      * Configurator implementation for URLs pointing to images.
      */
-    @SuppressWarnings({"unchecked","rawtypes"})
     private static class ImageColumnConfigurator extends UrlColumnConfigurator {
         final TopcatModel tcModel_;
         final boolean isRegion_;
         final boolean hasViewerChoice_;
-        final JComboBox viewerSelector_;
+        final JComboBox<Viewer> viewerSelector_;
         final NumberSelector xoffSelector_;
         final NumberSelector yoffSelector_;
 
@@ -104,7 +104,7 @@ public class GenericViewImageActivationType implements ActivationType {
             JComponent queryPanel = getQueryPanel();
             ActionListener forwarder = getActionForwarder();
 
-            viewerSelector_ = new JComboBox( viewers );
+            viewerSelector_ = new JComboBox<Viewer>( viewers );
             viewerSelector_.addActionListener( forwarder );
             xoffSelector_ = new NumberSelector( tcModel_, "X Offset" );
             xoffSelector_.comboBox_.addActionListener( forwarder );
@@ -164,7 +164,8 @@ public class GenericViewImageActivationType implements ActivationType {
             return getViewer().getSafety();
         }
         private Viewer getViewer() {
-            return (Viewer) viewerSelector_.getSelectedItem();
+            return viewerSelector_
+                  .getItemAt( viewerSelector_.getSelectedIndex() );
         }
     }
 
@@ -473,11 +474,10 @@ public class GenericViewImageActivationType implements ActivationType {
     /**
      * Component for choosing a numeric table column.
      */
-    @SuppressWarnings({"unchecked","rawtypes"})
     private static class NumberSelector {
         final String label_;
         final ColumnDataComboBoxModel model_;
-        final JComboBox comboBox_;
+        final JComboBox<ColumnData> comboBox_;
 
         /**
          * Constructor.
@@ -489,7 +489,7 @@ public class GenericViewImageActivationType implements ActivationType {
             label_ = label;
             model_ =
                 new ColumnDataComboBoxModel( tcModel, Number.class, false );
-            comboBox_ = ColumnDataComboBoxModel.createComboBox();
+            comboBox_ = new ColumnDataComboBox();
             comboBox_.setModel( model_ );
         }
 
