@@ -7,7 +7,6 @@ import java.awt.Font;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
-import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
@@ -17,6 +16,8 @@ import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
 import java.net.URLEncoder;
+import java.nio.charset.StandardCharsets;
+import java.util.Base64;
 import java.util.List;
 import java.util.Vector;
 import java.util.logging.Logger;
@@ -48,7 +49,6 @@ import uk.ac.starlink.table.gui.LabelledComponentStack;
 import uk.ac.starlink.table.gui.AbstractTableLoadDialog;
 import uk.ac.starlink.table.gui.TableLoader;
 import uk.ac.starlink.topcat.ResourceIcon;
-import uk.ac.starlink.util.Base64OutputStream;
 
 public class GavoTableLoadDialog extends AbstractTableLoadDialog {
 
@@ -309,18 +309,8 @@ public class GavoTableLoadDialog extends AbstractTableLoadDialog {
      * @return   base64 encoding of input buffer
      */
     private static String base64Encode( byte[] buf ) {
-        ByteArrayOutputStream bufout = new ByteArrayOutputStream();
-        Base64OutputStream b64out = new Base64OutputStream( bufout );
-        try {
-            b64out.write( buf );
-            b64out.endBase64();
-            b64out.flush();
-            b64out.close();
-            return new String( bufout.toByteArray(), "UTF-8" );
-        }
-        catch ( IOException e ) {  // shouldn't happen
-            throw new RuntimeException( "Can't base64-encode bytes???" );
-        }
+        return new String( Base64.getEncoder().encode( buf ),
+                           StandardCharsets.US_ASCII );
     }
 
     /**
