@@ -50,6 +50,7 @@ import uk.ac.starlink.topcat.BasicAction;
 import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.ToggleButtonModel;
 import uk.ac.starlink.ttools.func.CoordsRadians;
+import uk.ac.starlink.ttools.task.RowRunnerParameter;
 
 /**
  * Window for selecting the characteristics of and invoking a match 
@@ -127,7 +128,7 @@ public class MatchWindow extends AuxWindow implements ItemListener {
             new ToggleButtonModel( "Parallel execution", ResourceIcon.PARALLEL,
                                    "Set to run match using multithreaded "
                                  + "execution" );
-        parallelModel.setSelected( false );
+        parallelModel.setSelected( true );
 
         /* Set up an action to perform profiling during match. */
         profileModel =
@@ -235,7 +236,9 @@ public class MatchWindow extends AuxWindow implements ItemListener {
      */
     private MatchSpec makeMatchSpec( MatchEngine engine ) {
         Supplier<RowRunner> runnerFact =
-            () -> parallelModel.isSelected() ? RowRunner.DEFAULT : null;
+            () -> parallelModel.isSelected()
+                ? RowRunnerParameter.DFLT_MATCH_RUNNER
+                : RowRunner.SEQUENTIAL;
         switch( nTable ) {
             case 1:
                 return new IntraMatchSpec( engine, runnerFact );
