@@ -8,6 +8,8 @@ import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
+import javax.swing.event.ListSelectionEvent;
+import javax.swing.event.ListSelectionListener;
 import uk.ac.starlink.table.DefaultValueInfo;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.ValueInfo;
@@ -18,6 +20,10 @@ import uk.ac.starlink.ttools.cone.SiaConeSearcher;
 import uk.ac.starlink.util.ContentCoding;
 import uk.ac.starlink.util.gui.ShrinkWrapper;
 import uk.ac.starlink.vo.Capability;
+import uk.ac.starlink.vo.RegCapabilityInterface;
+import uk.ac.starlink.vo.RegistryPanel;
+import uk.ac.starlink.vo.SiaFormatOption;
+import uk.ac.starlink.vo.SiaVersion;
 import uk.ac.starlink.vo.SiapTableLoadDialog;
 
 /**
@@ -43,19 +49,22 @@ public class SiaMultiWindow extends DalMultiWindow {
      */
     private static class SiaMultiService implements DalMultiService {
 
-        @SuppressWarnings({"unchecked","rawtypes"})
-        private final JComboBox formatSelector_
-            = new JComboBox( SiapTableLoadDialog.getFormatOptions() );
-
+        private final JComboBox<Object> formatSelector_;
+        private final JComboBox<SiaVersion> versionSelector_;
         private final JComponent controlBox_;
+        private final JComponent versionBox_;
 
         /**
          * Constructor.
          */
         SiaMultiService() {
+            formatSelector_ =
+                new JComboBox<Object>( SiaFormatOption.getStandardOptions() );
             formatSelector_.setSelectedIndex( 0 );
             formatSelector_.setEditable( true );
 
+            versionSelector_ = new JComboBox<>( SiaVersion.values() );
+
             final JLabel formatLabel = new JLabel( "Image Format: " );
             controlBox_ = new JPanel() {
                 public void setEnabled( boolean enabled ) {
@@ -71,6 +80,10 @@ public class SiaMultiWindow extends DalMultiWindow {
             line.add( new ShrinkWrapper( formatSelector_ ) );
             line.add( Box.createHorizontalGlue() );
             controlBox_.add( line );
+
+            versionBox_ = Box.createHorizontalBox();
+            versionBox_.add( new JLabel( "SIA Version: " ) );
+            versionBox_.add( new ShrinkWrapper( versionSelector_ ) );
         }
 
         public String getName() {
@@ -112,11 +125,38 @@ public class SiaMultiWindow extends DalMultiWindow {
             return controlBox_;
         }
 
+        public JComponent getVersionComponent() {
+            return versionBox_;
+        }
+
+        public void init( final RegistryPanel regPanel ) {
+            ListSelectionListener servListener = new ListSelectionListener() {
+                public void valueChanged( ListSelectionEvent evt ) {
+                    RegCapabilityInterface[] intfs =
+                        regPanel.getSelectedCapabilities();
+                    if ( intfs.length == 1 ) {
+                        SiaVersion vers = SiaVersion.forInterface( intfs[ 0 ] );
+                        if ( vers != null ) {
+                            versionSelector_.setSelectedItem( vers );
+                        }   
+                    }
+                }
+            };
+            regPanel.getResourceSelectionModel()
+                    .addListSelectionListener( servListener );
+            regPanel.getCapabilitySelectionModel()
+                    .addListSelectionListener( servListener );
+        }
+
         public ConeSearcher createSearcher( URL url, StarTableFactory tfact,
                                             ContentCoding coding ) {
-            String format = (String) formatSelector_.getSelectedItem();
-            return new SiaConeSearcher( url.toString(), format, false, tfact,
-                                        coding );
+            SiaVersion version = 
+                versionSelector_
+               .getItemAt( versionSelector_.getSelectedIndex() );
+            SiaFormatOption format =
+                SiaFormatOption.fromObject( formatSelector_.getSelectedItem() );
+            return new SiaConeSearcher( url.toString(), version, format,
+                                        false, tfact, coding );
         }
 
         public boolean hasCoverages() {
