@@ -2,7 +2,9 @@ package uk.ac.starlink.topcat.plot2;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.function.Function;
 import uk.ac.starlink.table.DomainMapper;
+import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
@@ -86,8 +88,7 @@ public abstract class PositionCoordPanel extends CoordPanel {
             meta.setXmlDescription( meta0.getXmlDescription()
                                   + ( "<p>Applies to point "
                                     + iptxt + ".</p>" ) );
-            inputs[ ii ] =
-                new Input( meta, input0.getValueClass(), input0.getDomain() );
+            inputs[ ii ] = input0.withMeta( meta );
         }
         return new Coord() {
             public Input[] getInputs() {
@@ -99,9 +100,9 @@ public abstract class PositionCoordPanel extends CoordPanel {
             public StorageType getStorageType() {
                 return baseCoord.getStorageType();
             }
-            public Object inputToStorage( Object[] userCoords,
-                                          DomainMapper[] userMappers ) {
-                return baseCoord.inputToStorage( userCoords, userMappers );
+            public Function<Object[],?> inputStorage( ValueInfo[] infos,
+                                                      DomainMapper[] dms ) {
+                return baseCoord.inputStorage( infos, dms );
             }
         };
     }
